@@ -1,22 +1,12 @@
 package Term::Caca::Event::Quit;
-BEGIN {
-  $Term::Caca::Event::Quit::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $Term::Caca::Event::Quit::VERSION = '2.0_0';
-}
-
+our $AUTHORITY = 'cpan:YANICK';
+# ABSTRACT: event triggered when the display is quit
+$Term::Caca::Event::Quit::VERSION = '3.0.0';
 use strict;
 use warnings;
 
-use parent 'Term::Caca::Event';
-use Term::Caca;
-use Method::Signatures;
-
-sub new {
-    my $class = shift;
-    return bless $class->SUPER::new( @_ ), $class;
-}
+use Moose;
+extends 'Term::Caca::Event';
 
 1;
 
@@ -24,13 +14,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Term::Caca::Event::Quit
+Term::Caca::Event::Quit - event triggered when the display is quit
 
 =head1 VERSION
 
-version 2.0_0
+version 3.0.0
 
 =head1 AUTHORS
 
@@ -48,7 +40,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by John Beppu.
+This software is Copyright (c) 2018, 2013, 2011 by John Beppu.
 
 This is free software, licensed under:
 
